@@ -1,53 +1,9 @@
 package DBIx::HTML::LinkedMenus;
 
-# Name:
-#	DBIx::HTML::LinkedMenus
-#
-# Purpose:
-#	Convert db data to 2 linked HTML popup menus.
-#
-# Documentation:
-#	POD-style documentation is at the end. Extract it with pod2html.*.
-#
-# Note:
-#	o tab = 4 spaces || die
-#
-# Author:
-#	Ron Savage <ron@savage.net.au>
-#	Home page: http://savage.net.au/index.html
-
 use strict;
 use warnings;
 
-require 5.005_62;
-
-require Exporter;
-
-use Carp;
-
-our @ISA = qw(Exporter);
-
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-
-# This allows declaration	use Image::MagickWrapper ':all';
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
-our %EXPORT_TAGS = ( 'all' => [ qw(
-
-) ] );
-
-our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-
-our @EXPORT = qw(
-
-);
-our $VERSION = '1.10';
-
-# -----------------------------------------------
-
-# Preloaded methods go here.
+our $VERSION = '1.11';
 
 # -----------------------------------------------
 
@@ -758,6 +714,16 @@ modules, so don't be too keen on changing it :-).
 	DBIx::HTML::ClientDB
 	DBIx::HTML::PopupRadio
 
+=head1 Repository
+
+L<https://github.com/ronsavage/DBIx-HTML-LinkedMenus>
+
+=head1 Support
+
+Bugs should be reported via the CPAN bug tracker at
+
+L<https://github.com/ronsavage/DBIx-HTML-LinkedMenus/issues>
+
 =head1 Author
 
 C<DBIx::HTML::LinkedMenus> was written by Ron Savage I<E<lt>ron@savage.net.auE<gt>> in 2002.
